*********
Changelog
*********


in progress
===========


2019-06-30 0.1.0
================
- Basic implementation
- Add UUIDv4 identifiers
- Add ULID identifiers
- Add ``--upper`` and ``--lower`` options for output transformation
- Add Nagamani19 identifiers
- Add Gibberish words
- Add six-nibble-name integer slug
- Add MomentName short epoch slug (4-character nibbleword generator)
- Add release tooling
- Expose generators via HTTP API
- Improve performance of gibberish generator
- Wording: Use ``MomentName`` for generator
- Wording: Rename ``--wordlength`` to ``--size``
- Swap display order of generators
- Generate multiple tokens at once
- Make Nagamani19 generator obtain size, mapping it to precision
- Adjust Gibberish generator re. size parameter
- Improve main HTML UI with metadata
- Fix sdist package
